@@ -1,17 +1,15 @@
 """This file defines mcprotocol constant.
 """
-from typing import Tuple
-
 #PLC definetion
-Q_SERIES: str    = "Q"
-L_SERIES: str    = "L"
-QnA_SERIES: str  = "QnA"
-iQL_SERIES: str  = "iQ-L"
-iQR_SERIES: str  = "iQ-R"
+Q_SERIES    = "Q"
+L_SERIES    = "L"
+QnA_SERIES  = "QnA"
+iQL_SERIES  = "iQ-L"
+iQR_SERIES  = "iQ-R"
 
 #communication type
-COMMTYPE_BINARY: str = "binary"
-COMMTYPE_ASCII: str  = "ascii"
+COMMTYPE_BINARY = "binary"
+COMMTYPE_ASCII  = "ascii"
 
 class DeviceCodeError(Exception):
     """devicecode error. Device is not exsist.
@@ -21,7 +19,7 @@ class DeviceCodeError(Exception):
         devicename(str):    devicename. (ex: "Q", "P", both of them does not support mcprotocol.)
 
     """
-    def __init__(self, plctype: str, devicename: str):
+    def __init__(self, plctype, devicename):
         self.plctype = plctype
         self.devicename = devicename
 
@@ -91,7 +89,7 @@ class DeviceConstants:
         pass
     
     @staticmethod
-    def get_binary_devicecode(plctype: str, devicename: str) -> Tuple[int, int]:
+    def get_binary_devicecode(plctype, devicename):
         """Static method that returns devicecode from device name.
 
         Args:
@@ -179,7 +177,7 @@ class DeviceConstants:
             raise DeviceCodeError(plctype, devicename)
 
     @staticmethod
-    def get_ascii_devicecode(plctype: str, devicename: str) -> Tuple[str, int]:
+    def get_ascii_devicecode(plctype, devicename):
         """Static method that returns devicecode from device name.
 
         Args:
@@ -280,7 +278,7 @@ class DeviceConstants:
             raise DeviceCodeError(plctype, devicename)
 
     @staticmethod
-    def get_devicetype(plctype: str, devicename: str) -> str:
+    def get_devicetype(plctype, devicename):
         """Static method that returns device type "bit" or "wrod" type.
 
         Args:
